@@ -25,12 +25,10 @@ function doSearch(action, page, fout) {
     //
     form.operation.value = "search";
     //
-    if (fout == 1) {
-        form.target = "main";
-    } else {
-        form.target = "main";
-        form.elements[action].value = "true";
-    }
+    form.target = "main";
+    form.elements[action].value = "true";
     //
     form.submit();
+    //
+    form.elements[action].value = "";
 }
